==> eiffelstudio-18.07.10.1981.tar: F_code/C2/js95.c <==
/*
 * Code for class JSON_READER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "js95.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {JSON_READER}.make */
void F112_2707 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 111, Current, 0, 1, 2898);
	RTHOOK(1);
	F112_2709(Current, arg1);
	RTHOOK(2);
	RTEE;
}

/* {JSON_READER}.reset */
void F112_2708 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("reset", 111, Current, 0, 0, 2899);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current + O2706[Dtype(Current)-111]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	RTEE;
}

/* {JSON_READER}.set_representation */
void F112_2709 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("set_representation", 111, Current, 0, 1, 2900);
	RTGC;
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R9291[Dtype(arg1)-1189])(RTCW(arg1));
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R9292[Dtype(arg1)-1189])(RTCW(arg1));
	RTHOOK(3);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(4);
	F112_2708(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {JSON_READER}.next */
void F112_2711 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTCDT;
	
	
	RTEAA("next", 111, Current, 0, 0, 2902);
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current + O2706[dtype-111]))++;
	RTHOOK(2);
	RTEE;
}

/* {JSON_READER}.previous */
void F112_2712 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTCDT;
	
	
	RTEAA("previous", 111, Current, 0, 0, 2903);
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current + O2706[dtype-111]))--;
	RTHOOK(2);
	RTEE;
}

/* {JSON_READER}.skip_white_spaces */
void F112_2713 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("skip_white_spaces", 111, Current, 1, 0, 2904);
	RTGC;
	RTHOOK(1);
	loc1 = F112_2718(Current);
	for (;;) {
		RTHOOK(2);
		tb1 = '\01';
		if (!((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) ' ') && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\012')) && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\015')) && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\000')) && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\011')))) {
			tb1 = (EIF_BOOLEAN) !F112_2715(Current);
		}
		if (tb1) break;
		RTHOOK(3);
		F112_2711(Current);
		RTHOOK(4);
		loc1 = F112_2718(Current);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {JSON_READER}.json_substring */
EIF_REFERENCE F112_2714 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("json_substring", 111, Current, 0, 2, 2905);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R9251[Dtype(tr1)-1188])(RTCW(tr1), arg1, arg2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {JSON_READER}.has_next */
EIF_BOOLEAN F112_2715 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("has_next", 111, Current, 0, 0, 2906);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current + O2706[Dtype(Current)-111]);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 <= ti4_2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {JSON_READER}.representation */
EIF_REFERENCE F112_2717 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {JSON_READER}.actual */
EIF_CHARACTER_8 F112_2718 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_8 Result = ((EIF_CHARACTER_8) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("actual", 111, Current, 0, 0, 2909);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current + O2706[dtype-111]) > ti4_1)) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current);
		Result = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R7431[Dtype(tr1)-896])(RTCW(tr1), *(EIF_INTEGER_32 *)(Current + O2706[dtype-111])));
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit95 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/js95.c <==
/*
 * Code for class JSON_READER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "js95.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {JSON_READER}.make */
void F112_2707 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 111, Current, 0, 1, 2894);
	RTHOOK(1);
	F112_2709(Current, arg1);
	RTHOOK(2);
	RTEE;
}

/* {JSON_READER}.reset */
void F112_2708 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("reset", 111, Current, 0, 0, 2895);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_9_2_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	RTEE;
}

/* {JSON_READER}.set_representation */
void F112_2709 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("set_representation", 111, Current, 0, 1, 2896);
	RTGC;
	RTHOOK(1);
	F1204_11069(RTCW(arg1));
	RTHOOK(2);
	F1204_11070(RTCW(arg1));
	RTHOOK(3);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(4);
	F1748_19207(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {JSON_READER}.next */
void F112_2711 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("next", 111, Current, 0, 0, 2898);
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_9_2_0_0_))++;
	RTHOOK(3);
	RTEE;
}

/* {JSON_READER}.previous */
void F112_2712 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("previous", 111, Current, 0, 0, 2899);
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_9_2_0_0_))--;
	RTHOOK(3);
	RTEE;
}

/* {JSON_READER}.skip_white_spaces */
void F112_2713 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("skip_white_spaces", 111, Current, 1, 0, 2900);
	RTGC;
	RTHOOK(1);
	loc1 = F112_2719(Current);
	for (;;) {
		RTHOOK(2);
		tb1 = '\01';
		if (!((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) ' ') && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\012')) && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\015')) && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\000')) && (EIF_BOOLEAN)(loc1 != (EIF_CHARACTER_8) '\011')))) {
			tb1 = (EIF_BOOLEAN) !F112_2716(Current);
		}
		if (tb1) break;
		RTHOOK(3);
		F112_2711(Current);
		RTHOOK(4);
		loc1 = F112_2719(Current);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {JSON_READER}.has_json_substring */
EIF_BOOLEAN F112_2715 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("has_json_substring", 111, Current, 0, 3, 2902);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F1196_10723(RTCW(tr1), arg1, arg2, arg3, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_9_2_0_0_));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {JSON_READER}.has_next */
EIF_BOOLEAN F112_2716 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("has_next", 111, Current, 0, 0, 2903);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_9_2_0_0_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 <= ti4_2);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {JSON_READER}.actual */
EIF_CHARACTER_8 F112_2719 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_8 Result = ((EIF_CHARACTER_8) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("actual", 111, Current, 0, 0, 2906);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_9_2_0_0_) > ti4_1)) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
	} else {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current);
		Result = F1204_11050(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_9_2_0_0_));
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit95 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
